@@ -49,7 +49,10 @@ class uWSGIWebSocket(object):  # pragma: no cover
                 """Sets event when data becomes available to read on fd."""
                 while True:
                     event.set()
-                    select([fd], [], [])[0]
+                    try:
+                        select([fd], [], [])[0]
+                    except ValueError:
+                        break
             self._select_greenlet = gevent.spawn(
                 select_greenlet_runner,
                 uwsgi.connection_fd(),
@@ -131,7 +134,7 @@ class uWSGIWebSocket(object):  # pragma: no cover
                 # maybe there is something to receive, if not, at least
                 # ensure uWSGI does its ping/ponging
                 try:
-                    msg = uwsgi.websocket_recv()
+                    msg = uwsgi.websocket_recv_nb()
                 except IOError:  # connection closed
                     self._select_greenlet.kill()
                     return None
